Class: Hyperliquid::Exchange

Inherits:
Object
  • Object
show all
Defined in:
lib/hyperliquid/exchange.rb

Overview

Exchange API client for write operations (orders, cancels, etc.) Requires a private key for signing transactions

Constant Summary collapse

DEFAULT_SLIPPAGE =

Default slippage for market orders (5%)

0.05
SPOT_ASSET_THRESHOLD =

Spot assets have indices >= 10000

10_000

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:, signer:, info:, testnet: false, expires_after: nil) ⇒ Exchange

Initialize the exchange client

Parameters:

  • client (Hyperliquid::Client)

    HTTP client

  • signer (Hyperliquid::Signing::Signer)

    EIP-712 signer

  • info (Hyperliquid::Info)

    Info API client for metadata

  • testnet (Boolean) (defaults to: false)

    Whether targeting testnet (default: false)

  • expires_after (Integer, nil) (defaults to: nil)

    Optional global expiration timestamp



22
23
24
25
26
27
28
29
# File 'lib/hyperliquid/exchange.rb', line 22

def initialize(client:, signer:, info:, testnet: false, expires_after: nil)
  @client = client
  @signer = signer
  @info = info
  @testnet = testnet
  @expires_after = expires_after
  @asset_cache = nil
end

Instance Attribute Details

#expires_after=(value) ⇒ Object (writeonly)

Update the global expiration timestamp applied to subsequent L1 actions. ‘expires_after` is not supported on user-signed actions (e.g. `usd_send`, `withdraw_from_bridge`) and must be nil for those calls to succeed.

Parameters:

  • value (Integer, nil)

    Unix timestamp in milliseconds, or nil to clear



722
723
724
# File 'lib/hyperliquid/exchange.rb', line 722

def expires_after=(value)
  @expires_after = value
end

Instance Method Details

#addressString

Get the wallet address

Returns:

  • (String)

    Checksummed Ethereum address



33
34
35
# File 'lib/hyperliquid/exchange.rb', line 33

def address
  @signer.address
end

#agent_enable_dex_abstraction(vault_address: nil) ⇒ Hash

Enable HIP-3 DEX abstraction via agent (L1 action, enable only) This allows agents to enable DEX abstraction for the account they’re trading on behalf of

Parameters:

  • vault_address (String, nil) (defaults to: nil)

    Vault address if trading on behalf of a vault

Returns:

  • (Hash)

    Agent enable DEX abstraction response



668
669
670
671
672
673
674
675
676
677
# File 'lib/hyperliquid/exchange.rb', line 668

def agent_enable_dex_abstraction(vault_address: nil)
  nonce = timestamp_ms
  action = { type: 'agentEnableDexAbstraction' }
  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#agent_set_abstraction(abstraction:, vault_address: nil) ⇒ Hash

Set the agent abstraction mode (L1 action ‘agentSetAbstraction`).

Parameters:

  • abstraction (String)

    One of ‘u’ (unified), ‘p’ (portfolio margin), ‘i’ (isolated/disabled)

  • vault_address (String, nil) (defaults to: nil)

    Vault address if acting on behalf of a vault

Returns:

  • (Hash)

    Exchange response



683
684
685
686
687
688
689
690
691
692
# File 'lib/hyperliquid/exchange.rb', line 683

def agent_set_abstraction(abstraction:, vault_address: nil)
  nonce = timestamp_ms
  action = { type: 'agentSetAbstraction', abstraction: abstraction }
  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#approve_agent(agent_address:, agent_name: nil) ⇒ Hash

Authorize an agent wallet to trade on behalf of this account

Parameters:

  • agent_address (String)

    Agent’s Ethereum address

  • agent_name (String, nil) (defaults to: nil)

    Optional agent name (omitted from action if nil)

Returns:

  • (Hash)

    Approve agent response



573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/hyperliquid/exchange.rb', line 573

def approve_agent(agent_address:, agent_name: nil)
  nonce = timestamp_ms
  action = {
    type: 'approveAgent',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    agentAddress: agent_address,
    nonce: nonce
  }
  # agentName is always included in the signed message (empty string if nil),
  # but only included in the posted action if a name was provided (matches Python SDK)
  action[:agentName] = agent_name if agent_name
  signature = @signer.sign_user_signed_action(
    { agentAddress: agent_address, agentName: agent_name || '', nonce: nonce },
    'HyperliquidTransaction:ApproveAgent',
    Signing::EIP712::APPROVE_AGENT_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#approve_builder_fee(builder:, max_fee_rate:) ⇒ Hash

Approve a builder fee rate for a builder address Users must approve a builder before orders with that builder can be placed.

Parameters:

  • builder (String)

    Builder’s Ethereum address

  • max_fee_rate (String)

    Maximum fee rate (e.g., “0.01%” for 1 basis point)

Returns:

  • (Hash)

    Approve builder fee response



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/hyperliquid/exchange.rb', line 598

def approve_builder_fee(builder:, max_fee_rate:)
  nonce = timestamp_ms
  action = {
    type: 'approveBuilderFee',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    maxFeeRate: max_fee_rate,
    builder: builder,
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    { maxFeeRate: max_fee_rate, builder: builder, nonce: nonce },
    'HyperliquidTransaction:ApproveBuilderFee',
    Signing::EIP712::APPROVE_BUILDER_FEE_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#batch_modify(modifies:, vault_address: nil) ⇒ Hash

Modify multiple orders at once

Parameters:

  • modifies (Array<Hash>)

    Array of modify hashes with keys: :oid, :coin, :is_buy, :size, :limit_px, :order_type, :reduce_only, :cloid

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Batch modify response



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/hyperliquid/exchange.rb', line 255

def batch_modify(modifies:, vault_address: nil)
  nonce = timestamp_ms

  modify_wires = modifies.map do |m|
    order_wire = build_order_wire(
      coin: m[:coin],
      is_buy: m[:is_buy],
      size: m[:size],
      limit_px: m[:limit_px],
      order_type: m[:order_type] || { limit: { tif: 'Gtc' } },
      reduce_only: m[:reduce_only] || false,
      cloid: m[:cloid]
    )
    { oid: normalize_oid(m[:oid]), order: order_wire }
  end

  action = {
    type: 'batchModify',
    modifies: modify_wires
  }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#bulk_cancel(cancels:, vault_address: nil) ⇒ Hash

Cancel multiple orders by order ID

Parameters:

  • cancels (Array<Hash>)

    Array of cancel hashes with :coin and :oid

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Bulk cancel response



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/hyperliquid/exchange.rb', line 190

def bulk_cancel(cancels:, vault_address: nil)
  nonce = timestamp_ms

  cancel_wires = cancels.map do |c|
    { a: asset_index(c[:coin]), o: c[:oid] }
  end
  action = { type: 'cancel', cancels: cancel_wires }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#bulk_cancel_by_cloid(cancels:, vault_address: nil) ⇒ Hash

Cancel multiple orders by client order ID

Parameters:

  • cancels (Array<Hash>)

    Array of cancel hashes with :coin and :cloid

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Bulk cancel by cloid response



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/hyperliquid/exchange.rb', line 210

def bulk_cancel_by_cloid(cancels:, vault_address: nil)
  nonce = timestamp_ms

  cancel_wires = cancels.map do |c|
    { asset: asset_index(c[:coin]), cloid: normalize_cloid(c[:cloid]) }
  end
  action = { type: 'cancelByCloid', cancels: cancel_wires }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#bulk_orders(orders:, grouping: 'na', vault_address: nil, builder: nil) ⇒ Hash

Place multiple orders in a batch

Parameters:

  • orders (Array<Hash>)

    Array of order hashes with keys: :coin, :is_buy, :size, :limit_px, :order_type, :reduce_only, :cloid

  • grouping (String) (defaults to: 'na')

    Order grouping (“na”, “normalTpsl”, “positionTpsl”)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

  • builder (Hash, nil) (defaults to: nil)

    Builder fee config { b: “0xaddress”, f: fee_in_tenths_of_bp } (optional)

Returns:

  • (Hash)

    Bulk order response



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/hyperliquid/exchange.rb', line 84

def bulk_orders(orders:, grouping: 'na', vault_address: nil, builder: nil)
  nonce = timestamp_ms

  order_wires = orders.map do |o|
    build_order_wire(
      coin: o[:coin],
      is_buy: o[:is_buy],
      size: o[:size],
      limit_px: o[:limit_px],
      order_type: o[:order_type] || { limit: { tif: 'Gtc' } },
      reduce_only: o[:reduce_only] || false,
      cloid: o[:cloid]
    )
  end

  action = {
    type: 'order',
    orders: order_wires,
    grouping: grouping
  }
  action[:builder] = normalize_builder(builder) if builder

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#cancel(coin:, oid:, vault_address: nil) ⇒ Hash

Cancel a single order by order ID

Parameters:

  • coin (String)

    Asset symbol

  • oid (Integer)

    Order ID

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Cancel response



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/hyperliquid/exchange.rb', line 148

def cancel(coin:, oid:, vault_address: nil)
  nonce = timestamp_ms

  action = {
    type: 'cancel',
    cancels: [{ a: asset_index(coin), o: oid }]
  }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#cancel_by_cloid(coin:, cloid:, vault_address: nil) ⇒ Hash

Cancel a single order by client order ID

Parameters:

  • coin (String)

    Asset symbol

  • cloid (Cloid, String)

    Client order ID

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Cancel response



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/hyperliquid/exchange.rb', line 169

def cancel_by_cloid(coin:, cloid:, vault_address: nil)
  nonce = timestamp_ms
  cloid_raw = normalize_cloid(cloid)

  action = {
    type: 'cancelByCloid',
    cancels: [{ asset: asset_index(coin), cloid: cloid_raw }]
  }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#convert_to_multi_sig_user(authorized_users:, threshold:) ⇒ Hash

Convert this account into a multi-sig user (‘convertToMultiSigUser` user-signed action). The set of authorized signers and the threshold are JSON-encoded into the action’s ‘signers` field as required by the Hyperliquid protocol.

Parameters:

  • authorized_users (Array<String>)

    Authorized signer addresses; sorted before signing

  • threshold (Integer)

    Number of signatures required to authorize an action

Returns:

  • (Hash)

    Exchange response



777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
# File 'lib/hyperliquid/exchange.rb', line 777

def convert_to_multi_sig_user(authorized_users:, threshold:)
  nonce = timestamp_ms
  sorted_users = authorized_users.sort
  signers_json = JSON.generate({ authorizedUsers: sorted_users, threshold: threshold })
  action = {
    type: 'convertToMultiSigUser',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    signers: signers_json,
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    { signers: signers_json, nonce: nonce },
    'HyperliquidTransaction:ConvertToMultiSigUser',
    Signing::EIP712::CONVERT_TO_MULTI_SIG_USER_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#create_sub_account(name:) ⇒ Hash

Create a sub-account

Parameters:

  • name (String)

    Sub-account name

Returns:

  • (Hash)

    Creation response



499
500
501
502
503
504
# File 'lib/hyperliquid/exchange.rb', line 499

def (name:)
  nonce = timestamp_ms
  action = { type: 'createSubAccount', name: name }
  signature = @signer.sign_l1_action(action, nonce)
  post_action(action, signature, nonce, nil)
end

#gossip_priority_bid(slot_id:, ip:, max_gas:, vault_address: nil) ⇒ Hash

Submit a priority-bid gossip message (L1 action ‘gossipPriorityBid`). Used by validators / priority bidders to gossip a bid for a given slot.

Parameters:

  • slot_id (Integer)

    Slot identifier the bid applies to

  • ip (String)

    Bidder IP address (string form expected by the protocol)

  • max_gas (Integer)

    Maximum gas the bidder is willing to pay

  • vault_address (String, nil) (defaults to: nil)

    Vault address if acting on behalf of a vault

Returns:

  • (Hash)

    Exchange response



760
761
762
763
764
765
766
767
768
769
# File 'lib/hyperliquid/exchange.rb', line 760

def gossip_priority_bid(slot_id:, ip:, max_gas:, vault_address: nil)
  nonce = timestamp_ms
  action = { type: 'gossipPriorityBid', slotId: slot_id, ip: ip, maxGas: max_gas }
  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#market_close(coin:, size: nil, slippage: DEFAULT_SLIPPAGE, cloid: nil, vault_address: nil, builder: nil) ⇒ Hash

Close a position at market price

Parameters:

  • coin (String)

    Asset symbol (perps only)

  • size (Numeric, nil) (defaults to: nil)

    Size to close (nil = close entire position)

  • slippage (Float) (defaults to: DEFAULT_SLIPPAGE)

    Slippage tolerance (default: 5%)

  • cloid (Cloid, String, nil) (defaults to: nil)

    Client order ID (optional)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

  • builder (Hash, nil) (defaults to: nil)

    Builder fee config { b: “0xaddress”, f: fee_in_tenths_of_bp } (optional)

Returns:

  • (Hash)

    Order response

Raises:

  • (ArgumentError)


357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/hyperliquid/exchange.rb', line 357

def market_close(coin:, size: nil, slippage: DEFAULT_SLIPPAGE, cloid: nil, vault_address: nil, builder: nil)
  address = vault_address || @signer.address
  position = find_position(coin, address)
  raise ArgumentError, "No open position found for #{coin}" unless position

  szi = position.dig('position', 'szi').to_f
  is_buy = szi.negative?
  close_size = size || szi.abs
  slippage_price = calculate_slippage_price(coin, get_mid_price(coin), is_buy, slippage)

  order(
    coin: coin, is_buy: is_buy, size: close_size, limit_px: slippage_price,
    order_type: { limit: { tif: 'Ioc' } }, reduce_only: true,
    cloid: cloid, vault_address: vault_address, builder: builder
  )
end

#market_order(coin:, is_buy:, size:, slippage: DEFAULT_SLIPPAGE, vault_address: nil, builder: nil) ⇒ Hash

Place a market order (aggressive limit IoC with slippage)

Parameters:

  • coin (String)

    Asset symbol

  • is_buy (Boolean)

    True for buy, false for sell

  • size (String, Numeric)

    Order size

  • slippage (Float) (defaults to: DEFAULT_SLIPPAGE)

    Slippage tolerance (default: 0.05 = 5%)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

  • builder (Hash, nil) (defaults to: nil)

    Builder fee config { b: “0xaddress”, f: fee_in_tenths_of_bp } (optional)

Returns:

  • (Hash)

    Order response

Raises:

  • (ArgumentError)


122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/hyperliquid/exchange.rb', line 122

def market_order(coin:, is_buy:, size:, slippage: DEFAULT_SLIPPAGE, vault_address: nil, builder: nil)
  # Get current mid price (use dex-specific endpoint for HIP-3 assets)
  dex_prefix = extract_dex_prefix(coin)
  mids = dex_prefix ? @info.all_mids(dex: dex_prefix) : @info.all_mids
  mid = mids[coin]&.to_f
  raise ArgumentError, "Unknown asset or no price available: #{coin}" unless mid&.positive?

  # Apply slippage and round to appropriate precision
  slippage_price = calculate_slippage_price(coin, mid, is_buy, slippage)

  order(
    coin: coin,
    is_buy: is_buy,
    size: size,
    limit_px: slippage_price,
    order_type: { limit: { tif: 'Ioc' } },
    vault_address: vault_address,
    builder: builder
  )
end

#modify_order(oid:, coin:, is_buy:, size:, limit_px:, order_type: { limit: { tif: 'Gtc' } }, reduce_only: false, cloid: nil, vault_address: nil) ⇒ Hash

Modify a single existing order

Parameters:

  • oid (Integer, Cloid, String)

    Order ID or client order ID to modify

  • coin (String)

    Asset symbol (e.g., “BTC”)

  • is_buy (Boolean)

    True for buy, false for sell

  • size (String, Numeric)

    New order size

  • limit_px (String, Numeric)

    New limit price

  • order_type (Hash) (defaults to: { limit: { tif: 'Gtc' } })

    Order type config (default: { limit: { tif: “Gtc” } })

  • reduce_only (Boolean) (defaults to: false)

    Reduce-only flag (default: false)

  • cloid (Cloid, String, nil) (defaults to: nil)

    Client order ID for the modified order (optional)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Modify response



237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/hyperliquid/exchange.rb', line 237

def modify_order(oid:, coin:, is_buy:, size:, limit_px:,
                 order_type: { limit: { tif: 'Gtc' } },
                 reduce_only: false, cloid: nil, vault_address: nil)
  batch_modify(
    modifies: [{
      oid: oid, coin: coin, is_buy: is_buy, size: size,
      limit_px: limit_px, order_type: order_type,
      reduce_only: reduce_only, cloid: cloid
    }],
    vault_address: vault_address
  )
end

#noop(nonce: nil, vault_address: nil) ⇒ Hash

No-op L1 action — useful for burning a specific nonce slot without side effects.

Parameters:

  • nonce (Integer, nil) (defaults to: nil)

    Nonce to consume (defaults to current timestamp_ms)

  • vault_address (String, nil) (defaults to: nil)

    Vault address if acting on behalf of a vault

Returns:

  • (Hash)

    Exchange response



742
743
744
745
746
747
748
749
750
751
# File 'lib/hyperliquid/exchange.rb', line 742

def noop(nonce: nil, vault_address: nil)
  nonce ||= timestamp_ms
  action = { type: 'noop' }
  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#order(coin:, is_buy:, size:, limit_px:, order_type: { limit: { tif: 'Gtc' } }, reduce_only: false, cloid: nil, vault_address: nil, builder: nil) ⇒ Hash

Place a single order

Parameters:

  • coin (String)

    Asset symbol (e.g., “BTC”)

  • is_buy (Boolean)

    True for buy, false for sell

  • size (String, Numeric)

    Order size

  • limit_px (String, Numeric)

    Limit price

  • order_type (Hash) (defaults to: { limit: { tif: 'Gtc' } })

    Order type config (default: { limit: { tif: “Gtc” } })

  • reduce_only (Boolean) (defaults to: false)

    Reduce-only flag (default: false)

  • cloid (Cloid, String, nil) (defaults to: nil)

    Client order ID (optional)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

  • builder (Hash, nil) (defaults to: nil)

    Builder fee config { b: “0xaddress”, f: fee_in_tenths_of_bp } (optional)

Returns:

  • (Hash)

    Order response



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/hyperliquid/exchange.rb', line 48

def order(coin:, is_buy:, size:, limit_px:, order_type: { limit: { tif: 'Gtc' } },
          reduce_only: false, cloid: nil, vault_address: nil, builder: nil)
  nonce = timestamp_ms

  order_wire = build_order_wire(
    coin: coin,
    is_buy: is_buy,
    size: size,
    limit_px: limit_px,
    order_type: order_type,
    reduce_only: reduce_only,
    cloid: cloid
  )

  action = {
    type: 'order',
    orders: [order_wire],
    grouping: 'na'
  }
  action[:builder] = normalize_builder(builder) if builder

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#reload_metadata!Object

Clear the asset metadata cache Call this if metadata has been updated



798
799
800
# File 'lib/hyperliquid/exchange.rb', line 798

def reload_metadata!
  @asset_cache = nil
end

#schedule_cancel(time: nil, vault_address: nil) ⇒ Hash

Schedule automatic cancellation of all orders

Parameters:

  • time (Integer, nil) (defaults to: nil)

    UTC timestamp in milliseconds to cancel at (nil to activate with server default)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Schedule cancel response



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/hyperliquid/exchange.rb', line 335

def schedule_cancel(time: nil, vault_address: nil)
  nonce = timestamp_ms

  action = { type: 'scheduleCancel' }
  action[:time] = time if time

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#send_asset(destination:, source_dex:, destination_dex:, token:, amount:) ⇒ Hash

Move assets between DEX instances

Parameters:

  • destination (String)

    Destination wallet address

  • source_dex (String)

    Source DEX identifier

  • destination_dex (String)

    Destination DEX identifier

  • token (String)

    Token identifier

  • amount (String, Numeric)

    Amount to send

Returns:

  • (Hash)

    Transfer response



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/hyperliquid/exchange.rb', line 471

def send_asset(destination:, source_dex:, destination_dex:, token:, amount:)
  nonce = timestamp_ms
  action = {
    type: 'sendAsset',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    destination: destination,
    sourceDex: source_dex,
    destinationDex: destination_dex,
    token: token,
    amount: amount.to_s,
    fromSubAccount: '',
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    {
      destination: destination, sourceDex: source_dex, destinationDex: destination_dex,
      token: token, amount: amount.to_s, fromSubAccount: '', nonce: nonce
    },
    'HyperliquidTransaction:SendAsset',
    Signing::EIP712::SEND_ASSET_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#set_referrer(code:) ⇒ Hash

Set referral code

Parameters:

  • code (String)

    Referral code

Returns:

  • (Hash)

    Set referrer response



562
563
564
565
566
567
# File 'lib/hyperliquid/exchange.rb', line 562

def set_referrer(code:)
  nonce = timestamp_ms
  action = { type: 'setReferrer', code: code }
  signature = @signer.sign_l1_action(action, nonce)
  post_action(action, signature, nonce, nil)
end

#spot_send(amount:, destination:, token:) ⇒ Hash

Transfer a spot token to another address

Parameters:

  • amount (String, Numeric)

    Amount to send

  • destination (String)

    Destination wallet address

  • token (String)

    Token identifier

Returns:

  • (Hash)

    Transfer response



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/hyperliquid/exchange.rb', line 401

def spot_send(amount:, destination:, token:)
  nonce = timestamp_ms
  action = {
    type: 'spotSend',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    destination: destination,
    token: token,
    amount: amount.to_s,
    time: nonce
  }
  signature = @signer.sign_user_signed_action(
    { destination: destination, token: token, amount: amount.to_s, time: nonce },
    'HyperliquidTransaction:SpotSend',
    Signing::EIP712::SPOT_SEND_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#sub_account_spot_transfer(sub_account_user:, is_deposit:, token:, amount:) ⇒ Hash

Transfer spot tokens to/from a sub-account

Parameters:

  • sub_account_user (String)

    Sub-account wallet address

  • is_deposit (Boolean)

    True to deposit into sub-account, false to withdraw

  • token (String)

    Token identifier

  • amount (String, Numeric)

    Amount to transfer

Returns:

  • (Hash)

    Transfer response



529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/hyperliquid/exchange.rb', line 529

def (sub_account_user:, is_deposit:, token:, amount:)
  nonce = timestamp_ms
  action = {
    type: 'subAccountSpotTransfer',
    subAccountUser: ,
    isDeposit: is_deposit,
    token: token,
    amount: amount.to_s
  }
  signature = @signer.sign_l1_action(action, nonce)
  post_action(action, signature, nonce, nil)
end

#sub_account_transfer(sub_account_user:, is_deposit:, usd:) ⇒ Hash

Transfer USDC to/from a sub-account

Parameters:

  • sub_account_user (String)

    Sub-account wallet address

  • is_deposit (Boolean)

    True to deposit into sub-account, false to withdraw

  • usd (Numeric)

    Amount in USD

Returns:

  • (Hash)

    Transfer response



511
512
513
514
515
516
517
518
519
520
521
# File 'lib/hyperliquid/exchange.rb', line 511

def (sub_account_user:, is_deposit:, usd:)
  nonce = timestamp_ms
  action = {
    type: 'subAccountTransfer',
    subAccountUser: ,
    isDeposit: is_deposit,
    usd: float_to_usd_int(usd)
  }
  signature = @signer.sign_l1_action(action, nonce)
  post_action(action, signature, nonce, nil)
end

#token_delegate(validator:, wei:, is_undelegate:) ⇒ Hash

Delegate or undelegate HYPE tokens to a validator

Parameters:

  • validator (String)

    Validator’s Ethereum address

  • wei (Integer)

    Amount as float * 1e8 (e.g., 1 HYPE = 100_000_000)

  • is_undelegate (Boolean)

    True to undelegate, false to delegate

Returns:

  • (Hash)

    Token delegate response



621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/hyperliquid/exchange.rb', line 621

def token_delegate(validator:, wei:, is_undelegate:)
  nonce = timestamp_ms
  action = {
    type: 'tokenDelegate',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    validator: validator,
    wei: wei,
    isUndelegate: is_undelegate,
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    { validator: validator, wei: wei, isUndelegate: is_undelegate, nonce: nonce },
    'HyperliquidTransaction:TokenDelegate',
    Signing::EIP712::TOKEN_DELEGATE_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#update_isolated_margin(coin:, amount:, vault_address: nil) ⇒ Hash

Add or remove isolated margin for a position

Parameters:

  • coin (String)

    Asset symbol (perps only)

  • amount (Numeric)

    Amount in USD (positive to add, negative to remove)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Margin update response



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/hyperliquid/exchange.rb', line 313

def update_isolated_margin(coin:, amount:, vault_address: nil)
  nonce = timestamp_ms

  action = {
    type: 'updateIsolatedMargin',
    asset: asset_index(coin),
    isBuy: true,
    ntli: float_to_usd_int(amount)
  }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#update_leverage(coin:, leverage:, is_cross: true, vault_address: nil) ⇒ Hash

Set cross or isolated leverage for a coin

Parameters:

  • coin (String)

    Asset symbol (perps only)

  • leverage (Integer)

    Leverage value

  • is_cross (Boolean) (defaults to: true)

    True for cross margin, false for isolated (default: true)

  • vault_address (String, nil) (defaults to: nil)

    Vault address for vault trading (optional)

Returns:

  • (Hash)

    Leverage update response



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/hyperliquid/exchange.rb', line 290

def update_leverage(coin:, leverage:, is_cross: true, vault_address: nil)
  nonce = timestamp_ms

  action = {
    type: 'updateLeverage',
    asset: asset_index(coin),
    isCross: is_cross,
    leverage: leverage
  }

  signature = @signer.sign_l1_action(
    action, nonce,
    vault_address: vault_address,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, vault_address)
end

#usd_class_transfer(amount:, to_perp:) ⇒ Hash

Move USDC between perp and spot accounts

Parameters:

  • amount (String, Numeric)

    Amount to transfer

  • to_perp (Boolean)

    True to move to perp, false to move to spot

Returns:

  • (Hash)

    Transfer response



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/hyperliquid/exchange.rb', line 424

def usd_class_transfer(amount:, to_perp:)
  nonce = timestamp_ms
  action = {
    type: 'usdClassTransfer',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    amount: amount.to_s,
    toPerp: to_perp,
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    { amount: amount.to_s, toPerp: to_perp, nonce: nonce },
    'HyperliquidTransaction:UsdClassTransfer',
    Signing::EIP712::USD_CLASS_TRANSFER_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#usd_send(amount:, destination:) ⇒ Hash

Transfer USDC to another address

Parameters:

  • amount (String, Numeric)

    Amount to send

  • destination (String)

    Destination wallet address

Returns:

  • (Hash)

    Transfer response



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/hyperliquid/exchange.rb', line 378

def usd_send(amount:, destination:)
  nonce = timestamp_ms
  action = {
    type: 'usdSend',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    destination: destination,
    amount: amount.to_s,
    time: nonce
  }
  signature = @signer.sign_user_signed_action(
    { destination: destination, amount: amount.to_s, time: nonce },
    'HyperliquidTransaction:UsdSend',
    Signing::EIP712::USD_SEND_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#use_big_blocks(enable:) ⇒ Hash

Toggle EVM big-blocks mode for this account (‘evmUserModify` L1 action). When enabled, EVM transactions from this account are routed to big blocks.

Parameters:

  • enable (Boolean)

    True to enable big blocks, false to disable

Returns:

  • (Hash)

    Exchange response



728
729
730
731
732
733
734
735
736
# File 'lib/hyperliquid/exchange.rb', line 728

def use_big_blocks(enable:)
  nonce = timestamp_ms
  action = { type: 'evmUserModify', usingBigBlocks: enable }
  signature = @signer.sign_l1_action(
    action, nonce,
    expires_after: @expires_after
  )
  post_action(action, signature, nonce, nil)
end

#user_dex_abstraction(enabled:, user: nil) ⇒ Hash

Enable or disable HIP-3 DEX abstraction for automatic collateral transfers When enabled, collateral is automatically transferred to HIP-3 dexes when trading

Parameters:

  • enabled (Boolean)

    True to enable, false to disable DEX abstraction

  • user (String, nil) (defaults to: nil)

    User address (defaults to signer address)

Returns:

  • (Hash)

    User DEX abstraction response



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/hyperliquid/exchange.rb', line 645

def user_dex_abstraction(enabled:, user: nil)
  nonce = timestamp_ms
  user_address = user || @signer.address
  action = {
    type: 'userDexAbstraction',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    user: user_address,
    enabled: enabled,
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    { user: user_address, enabled: enabled, nonce: nonce },
    'HyperliquidTransaction:UserDexAbstraction',
    Signing::EIP712::USER_DEX_ABSTRACTION_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#user_set_abstraction(user:, abstraction:) ⇒ Hash

Set the abstraction mode for a user (‘userSetAbstraction` user-signed action). The `user` address is lowercased to match the Python SDK and protocol expectations.

Parameters:

  • user (String)

    Wallet address whose abstraction is being set

  • abstraction (String)

    One of ‘u’ (unified), ‘p’ (portfolio margin), ‘i’ (isolated/disabled)

Returns:

  • (Hash)

    Exchange response



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
# File 'lib/hyperliquid/exchange.rb', line 699

def user_set_abstraction(user:, abstraction:)
  nonce = timestamp_ms
  user_lower = user.downcase
  action = {
    type: 'userSetAbstraction',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    user: user_lower,
    abstraction: abstraction,
    nonce: nonce
  }
  signature = @signer.sign_user_signed_action(
    { user: user_lower, abstraction: abstraction, nonce: nonce },
    'HyperliquidTransaction:UserSetAbstraction',
    Signing::EIP712::USER_SET_ABSTRACTION_TYPES
  )
  post_action(action, signature, nonce, nil)
end

#vault_transfer(vault_address:, is_deposit:, usd:) ⇒ Hash

Deposit or withdraw USDC to/from a vault

Parameters:

  • vault_address (String)

    Vault wallet address

  • is_deposit (Boolean)

    True to deposit, false to withdraw

  • usd (Numeric)

    Amount in USD

Returns:

  • (Hash)

    Vault transfer response



547
548
549
550
551
552
553
554
555
556
557
# File 'lib/hyperliquid/exchange.rb', line 547

def vault_transfer(vault_address:, is_deposit:, usd:)
  nonce = timestamp_ms
  action = {
    type: 'vaultTransfer',
    vaultAddress: vault_address,
    isDeposit: is_deposit,
    usd: float_to_usd_int(usd)
  }
  signature = @signer.sign_l1_action(action, nonce)
  post_action(action, signature, nonce, nil)
end

#withdraw_from_bridge(amount:, destination:) ⇒ Hash

Withdraw USDC via the bridge

Parameters:

  • amount (String, Numeric)

    Amount to withdraw

  • destination (String)

    Destination wallet address

Returns:

  • (Hash)

    Withdrawal response



446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/hyperliquid/exchange.rb', line 446

def withdraw_from_bridge(amount:, destination:)
  nonce = timestamp_ms
  action = {
    type: 'withdraw3',
    signatureChainId: '0x66eee',
    hyperliquidChain: Signing::EIP712.hyperliquid_chain(testnet: @testnet),
    destination: destination,
    amount: amount.to_s,
    time: nonce
  }
  signature = @signer.sign_user_signed_action(
    { destination: destination, amount: amount.to_s, time: nonce },
    'HyperliquidTransaction:Withdraw',
    Signing::EIP712::WITHDRAW_TYPES
  )
  post_action(action, signature, nonce, nil)
end